package cn.timer.api.utils.email;

import cn.timer.api.utils.ZpglMessageTemplate;
import org.apache.commons.lang3.ArrayUtils;
import org.springframework.beans.factory.annotation.Value;
import org.springframework.mail.SimpleMailMessage;
import org.springframework.mail.javamail.JavaMailSender;
import org.springframework.mail.javamail.MimeMessageHelper;
import org.springframework.stereotype.Component;
import org.thymeleaf.context.Context;
import org.thymeleaf.util.MapUtils;
import org.thymeleaf.util.StringUtils;

import javax.mail.MessagingException;
import javax.mail.internet.MimeMessage;
import java.util.Map;

/**
 * @author wuqingjun
 * @email 284718418@qq.com
 * @date 2022/4/13
 */
@Component
public class EmailUtils {

    /**
     * 发送人邮箱
     */
    private static String from;

    @Value("${spring.mail.username}")
    private void setFrom(String from) {
        EmailUtils.from = from;
    }

    /**
     * 解析页
     */
    private static String html;

    @Value("${spring.mail.thymeleaf-html}")
    private void setHtml(String html) {
        EmailUtils.html = html;
    }


    /**
     * 普通发送邮件
     *
     * @param text
     * @param toMails
     * @throws MessagingException
     */
    public static int sendSimpleMail(JavaMailSender javaMailSender,String text,String subject, String... toMails) {
        // text or toMails is null
        if (StringUtils.isEmpty(text) || ArrayUtils.isEmpty(toMails)) {
            return 0;
        }
        try {
            SimpleMailMessage message = new SimpleMailMessage();
            message.setSubject(subject);
            message.setFrom(from);
            message.setBcc(from);
            message.setTo(toMails);
            message.setText(text);
            javaMailSender.send(message);
        } catch (Exception e) {
            e.printStackTrace();
            return 0;
        }
        return 1;
    }

    /**
     * 发送 thymeleaf 页面邮件 - 单参数
     *
     * @param goldCoinCode
     * @param toMails
     * @param subject
     * @throws MessagingException
     */
    public static int sendThymeleafMail(JavaMailSender javaMailSender,String goldCoinCode, String subject, String... toMails) {
        // goldCoinCode is null
        if (StringUtils.isEmpty(goldCoinCode)) {
            return 0;
        }
        // 发送邮件
        return sendThymeleafMail(javaMailSender,null, goldCoinCode, subject, toMails);
    }

    /**
     * 发送 thymeleaf 页面邮件 - 多参数
     *
     * @param map
     * @param toMails
     * @param subject
     * @throws MessagingException
     */
    public static int sendThymeleafMail(JavaMailSender javaMailSender,Map<String, Object> map,String subject, String... toMails) {
        // map is null
        if (MapUtils.isEmpty(map)) {
            return 0;
        }
        // 发送邮件
        return sendThymeleafMail(javaMailSender,map, null, subject, toMails);
    }

    /**
     * 发送 thymeleaf 页面邮件 - 最终执行
     *
     * @param map
     * @param toMails
     * @param subject
     * @throws MessagingException
     */
    private static int sendThymeleafMail(JavaMailSender javaMailSender, Map<String, Object> map, String goldCoinCode,String subject, String... toMails) {
        // toMails is null
        if (ArrayUtils.isEmpty(toMails)) {
            return 0;
        }
        try {
            MimeMessage mimeMessage = javaMailSender.createMimeMessage();
            MimeMessageHelper helper = new MimeMessageHelper(mimeMessage, true);
            helper.setSubject(subject);
            helper.setFrom(from);
            helper.setBcc(from);
            helper.setTo(toMails);
            Context context = new Context();
            if (!MapUtils.isEmpty(map)) {
                context.setVariables(map);
            } else {
                context.setVariable("GoldCoinCode", goldCoinCode);
            }

            //String process = templateEngine.process(html, context);
            helper.setText(ZpglMessageTemplate.OFFER_TEMPLATE,true);
            javaMailSender.send(mimeMessage);
        } catch (MessagingException e) {
            e.printStackTrace();
            return 0;
        }
        return 1;
    }


}
